<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_US">
<context>
    <name>About</name>
    <message>
        <location filename="../about.ui" line="14"/>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.ui" line="47"/>
        <source>Packet Sender</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.ui" line="136"/>
        <source>Written by Dan Nagle and published by NagleCode, LLC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.ui" line="165"/>
        <source>TextLabel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.ui" line="185"/>
        <source>PacketSender.com</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="26"/>
        <source>
Commit Hash: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="31"/>
        <source>About Packet Sender</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BruceThePoodle</name>
    <message>
        <location filename="../brucethepoodle.ui" line="26"/>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../brucethepoodle.cpp" line="29"/>
        <source>Bruce The Poodle!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CloudUI</name>
    <message>
        <location filename="../cloudui.ui" line="14"/>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="28"/>
        <source>Account</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="49"/>
        <source>Packet Sender Cloud</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="73"/>
        <source>Username</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="91"/>
        <source>Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="112"/>
        <source>Confirm Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="131"/>
        <source>Remember Login</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="140"/>
        <location filename="../cloudui.cpp" line="466"/>
        <source>Login</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="150"/>
        <location filename="../cloudui.cpp" line="465"/>
        <source>Create a new account.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="187"/>
        <source>Privacy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="194"/>
        <source>Terms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="214"/>
        <source>cloud.packetsender.com/help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="228"/>
        <source>Import</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="239"/>
        <source>Import From URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="248"/>
        <location filename="../cloudui.ui" line="372"/>
        <source>Description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="268"/>
        <source>View URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="283"/>
        <source>Delete Packet Set</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="290"/>
        <source>Import Packet Set</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="307"/>
        <source>Save / Share</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="313"/>
        <source>You are sharing.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="322"/>
        <source>Packet Set Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="336"/>
        <source>Public Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="359"/>
        <source>Make Public</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="401"/>
        <source>Save to Packet Sender Cloud</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../cloudui.cpp" line="83"/>
        <source>Cloud</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../cloudui.cpp" line="100"/>
        <source>Saving </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../cloudui.cpp" line="100"/>
        <source> packet set to cloud</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../cloudui.cpp" line="470"/>
        <source>Login instead.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../cloudui.cpp" line="471"/>
        <source>Sign-up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../cloudui.cpp" line="528"/>
        <source>Delete Set</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../cloudui.cpp" line="533"/>
        <source>Delete the set </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../cloudui.cpp" line="533"/>
        <source> from cloud?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>IrisAndMarigold</name>
    <message>
        <location filename="../irisandmarigold.ui" line="26"/>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LanguageChooser</name>
    <message>
        <location filename="../languagechooser.ui" line="14"/>
        <source>Choose Language</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../languagechooser.ui" line="46"/>
        <source>Español</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../languagechooser.ui" line="79"/>
        <source>English</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../languagechooser.ui" line="115"/>
        <source>Deutsch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../languagechooser.ui" line="151"/>
        <source>Français</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../languagechooser.ui" line="187"/>
        <source>Italiano</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../languagechooser.ui" line="206"/>
        <source>OK / Aceptar</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>MainWindow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="35"/>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="48"/>
        <source>Packet Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="72"/>
        <source>Request</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="79"/>
        <source>URL path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="93"/>
        <source>ASCII</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="100"/>
        <source>Generate Data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="107"/>
        <source>ASCII representation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="117"/>
        <source>Load File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="128"/>
        <source>HEX</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="135"/>
        <source>HEX representation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="151"/>
        <source>Address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="158"/>
        <source>IPv4, IPv6, DNS Lookup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <source>Port</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="184"/>
        <source>1 to 65535</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="194"/>
        <source>Resend Delay</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="207"/>
        <source>0.0/blank off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="230"/>
        <source>TCP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="239"/>
        <source>UDP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="248"/>
        <source>SSL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="257"/>
        <source>HTTP Get</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="266"/>
        <source>HTTP Post</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="275"/>
        <source>HTTPS Get</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="284"/>
        <source>HTTPS Post</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="296"/>
        <location filename="../mainwindow.cpp" line="1074"/>
        <location filename="../mainwindow.cpp" line="1732"/>
        <source>Send</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="303"/>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="332"/>
        <source>Search Saved Packets...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="360"/>
        <source>Generate Panel!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="383"/>
        <source>Delete Saved Packet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="390"/>
        <source>Persistent TCP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="427"/>
        <source>Clear Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="447"/>
        <source>Log Traffic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="457"/>
        <source>Save Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="464"/>
        <source>Save Traffic Packet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="471"/>
        <source>Copy to Clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="519"/>
        <source>&amp;File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="528"/>
        <source>&amp;Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="539"/>
        <source>&amp;Tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="548"/>
        <source>&amp;Multicast</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="554"/>
        <source>Panels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="572"/>
        <source>E&amp;xit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="581"/>
        <source>&amp;Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="590"/>
        <source>&amp;About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="599"/>
        <source>&amp;Import Database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="608"/>
        <source>&amp;Export Database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="613"/>
        <source>Persistent Connection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="622"/>
        <source>&amp;Subnet Calculator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="631"/>
        <source>D&amp;onate (Thank You!)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="636"/>
        <source>Documentation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="645"/>
        <source>&amp;Documentation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="650"/>
        <source>Export To Cloud</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="659"/>
        <source>&amp;Cloud Save and Share</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="668"/>
        <source>&amp;Join/Leave IPv4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="677"/>
        <source>Android App</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="686"/>
        <source>iOS App</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="695"/>
        <source>Follow on Twitter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="704"/>
        <source>Connect on LinkedIn</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="713"/>
        <source>Intense &amp;Traffic Generator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="722"/>
        <source>Forums</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="727"/>
        <source>Load Starter Panel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="732"/>
        <source>Empty Panel Project</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="741"/>
        <source>Wake-On-LAN / Magic Packet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="594"/>
        <location filename="../mainwindow.cpp" line="622"/>
        <source>Updates.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="598"/>
        <source>There is a new Packet Sender available.

Download?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="626"/>
        <source>Let Packet Sender check for updates weekly?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="670"/>
        <source>Packet Sender Updated!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="674"/>
        <source>Updated to </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="674"/>
        <source>!

Would you like to read the release notes?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="735"/>
        <source>Clear Log </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="760"/>
        <location filename="../mainwindow.cpp" line="782"/>
        <location filename="../mainwindow.cpp" line="803"/>
        <source> Ports</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="766"/>
        <source>UDP Server Disabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="788"/>
        <source>SSL Server Disabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="810"/>
        <source>TCP Server Disabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1030"/>
        <location filename="../mainwindow.cpp" line="1271"/>
        <source>Multicast detected.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1034"/>
        <source>Do you wish to join the multicast group?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1050"/>
        <location filename="../mainwindow.cpp" line="1293"/>
        <source>Broadcast with responses!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1054"/>
        <location filename="../mainwindow.cpp" line="1297"/>
        <source>You are sending a broadcast packet with responses enabled.

This could cause traffic flooding. Continue?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="234"/>
        <location filename="../mainwindow.cpp" line="1068"/>
        <location filename="../mainwindow.cpp" line="1333"/>
        <location filename="../mainwindow.cpp" line="1939"/>
        <source>Resending</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1074"/>
        <source>bytes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1101"/>
        <source>Name cannot be blank.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1105"/>
        <source>Name is empty.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1155"/>
        <source>This computer does not support SSL.

Expected SSL:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1159"/>
        <source>No SSL Library.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1212"/>
        <source>Address cannot be blank.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1216"/>
        <source>Address is empty.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1227"/>
        <source>Port cannot be blank/zero.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1231"/>
        <source>Port is zero.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1245"/>
        <source>IPv6?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1249"/>
        <source>Enable IPv6 support?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1275"/>
        <source>Join UDP multicast group?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1313"/>
        <source>Resend TCP with persistent connections!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1317"/>
        <source>You are resending a TCP packet with persistent connections. The UI could spawn numerous windows! 

Uncheck persistent connection? (Recommended)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1352"/>
        <location filename="../mainwindow.cpp" line="2002"/>
        <source>No packets selected.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1356"/>
        <source>Select a packet.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1395"/>
        <source>Invalid Address / DNS failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1418"/>
        <source>Invalid Port</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1862"/>
        <source>Clear Log (0)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1881"/>
        <source>Save Packet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1882"/>
        <source>Packet name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2006"/>
        <source>Clipboard unchanged.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2067"/>
        <source>Save Traffic Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2068"/>
        <source>log (*.log)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2086"/>
        <source>TIME</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2086"/>
        <source>From IP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2086"/>
        <source>From Port</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2086"/>
        <source>To IP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2087"/>
        <source>To Port</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2087"/>
        <source>Method</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2087"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2262"/>
        <source>Import JSON</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2264"/>
        <location filename="../mainwindow.cpp" line="2331"/>
        <source>JSON db (*.json)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2288"/>
        <location filename="../mainwindow.cpp" line="2425"/>
        <source>Found </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2288"/>
        <location filename="../mainwindow.cpp" line="2425"/>
        <source> packets!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2292"/>
        <location filename="../mainwindow.cpp" line="2429"/>
        <source>Import </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2292"/>
        <location filename="../mainwindow.cpp" line="2429"/>
        <source> packets?

Packet Sender will overwrite packets with the same name.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2295"/>
        <location filename="../mainwindow.cpp" line="2316"/>
        <location filename="../mainwindow.cpp" line="2432"/>
        <location filename="../mainwindow.cpp" line="2453"/>
        <source>Import Cancelled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2303"/>
        <source>Import Finished</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2309"/>
        <location filename="../mainwindow.cpp" line="2446"/>
        <source>Not a database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2313"/>
        <location filename="../mainwindow.cpp" line="2450"/>
        <source>Found no packets in this file. It may not be a Packet Sender export</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2330"/>
        <source>Save JSON</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2352"/>
        <location filename="../mainwindow.cpp" line="2485"/>
        <source>Export: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2356"/>
        <source>Could not save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2360"/>
        <source>Could not open </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2406"/>
        <location filename="../mainwindow.cpp" line="2531"/>
        <source>Import File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2408"/>
        <location filename="../mainwindow.cpp" line="2463"/>
        <source>INI db (*.ini)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2462"/>
        <source>Save File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2533"/>
        <source>*.*</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2557"/>
        <source>Max size exceeded!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2561"/>
        <source>The HEX field supports up to 10,922 bytes. The data has been truncated.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2567"/>
        <source>Loading </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2567"/>
        <source> bytes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2801"/>
        <source>Invalid MAC Address.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MulticastSetup</name>
    <message>
        <location filename="../multicastsetup.ui" line="14"/>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../multicastsetup.ui" line="22"/>
        <source>IP Multicast Address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../multicastsetup.ui" line="29"/>
        <source>Join</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../multicastsetup.ui" line="54"/>
        <source>Leave All Groups</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../multicastsetup.cpp" line="15"/>
        <source>IPv4 Multicast Setup (Experimental)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../multicastsetup.cpp" line="31"/>
        <source>There are no bound UDP ports</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../multicastsetup.cpp" line="34"/>
        <source>UDP socket bound to </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../multicastsetup.cpp" line="36"/>
        <source> will join the multicast group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../multicastsetup.cpp" line="59"/>
        <source>Not Multicast.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../multicastsetup.cpp" line="63"/>
        <source>IP must be an IPv4 multicast address.
(224.0.0.0 to 239.255.255.255)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../multicastsetup.cpp" line="74"/>
        <source>IPv4-only.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../multicastsetup.cpp" line="78"/>
        <source>Packet Sender supports multicast when binded to IPv4. 
Turn off IPv6 and switch to IPv4 mode?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PacketLogModel</name>
    <message>
        <location filename="../packetlogmodel.cpp" line="83"/>
        <source>Data portion is </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../packetlogmodel.cpp" line="83"/>
        <source> bytes</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PacketNetwork</name>
    <message>
        <location filename="../packetnetwork.cpp" line="246"/>
        <source>Port bind error.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../packetnetwork.cpp" line="250"/>
        <source>Packet Sender attempted (and failed) to bind to port [PORT], which is less than 1024. 

Privileged ports requires running Packet Sender with admin-level / root permissions.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../packetnetwork.cpp" line="251"/>
        <source>Packet Sender attempted (and failed) to bind to port [PORT].

 - Are you running multiple instances? 

 - Trying to bind to a missing custom IP?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PanelGenerator</name>
    <message>
        <location filename="../panelgenerator.ui" line="20"/>
        <source>MainWindow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="56"/>
        <location filename="../panelgenerator.ui" line="69"/>
        <location filename="../panelgenerator.ui" line="82"/>
        <location filename="../panelgenerator.ui" line="95"/>
        <location filename="../panelgenerator.ui" line="108"/>
        <location filename="../panelgenerator.ui" line="121"/>
        <location filename="../panelgenerator.ui" line="134"/>
        <location filename="../panelgenerator.ui" line="147"/>
        <location filename="../panelgenerator.ui" line="160"/>
        <source>PushButton</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="183"/>
        <source>&amp;File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="192"/>
        <source>&amp;Export</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="203"/>
        <source>&amp;Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="209"/>
        <source>S&amp;ettings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="223"/>
        <source>&amp;Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="226"/>
        <source>Ctrl+S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="231"/>
        <source>Save &amp;As...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="236"/>
        <source>&amp;Import Panels File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="239"/>
        <source>Ctrl+O</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="244"/>
        <source>Portable &amp;Windows Package</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="247"/>
        <source>F5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="252"/>
        <source>&amp;Documentation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="255"/>
        <source>F1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="260"/>
        <source>Panel Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="265"/>
        <source>Panel ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="273"/>
        <source>Starter Panel:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="278"/>
        <location filename="../panelgenerator.cpp" line="48"/>
        <source>Delete Panel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="283"/>
        <source>&amp;Panels File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="288"/>
        <source>Portable &amp;macOS Package</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="293"/>
        <source>Portable Linux Package</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="298"/>
        <source>&amp;New Panel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="301"/>
        <source>Ctrl+N</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="40"/>
        <source>Panels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="47"/>
        <source>Load Panel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="52"/>
        <location filename="../panelgenerator.cpp" line="364"/>
        <source>Viewing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="135"/>
        <source>URL or File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="136"/>
        <source>URL or File:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="155"/>
        <source>Link text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="156"/>
        <source>Link text:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="321"/>
        <source>Confirm delete.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="325"/>
        <source>Delete </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="331"/>
        <source>Deleting </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="339"/>
        <source>Panel </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="341"/>
        <source>Set Panel Name: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="342"/>
        <source>Set Panel ID: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="346"/>
        <source>Packet Sender Panel: New Panel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="347"/>
        <source>Set Panel Name: New Panel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="348"/>
        <source>Set Panel ID: New Panel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="354"/>
        <source>Starter Panel: Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="356"/>
        <source>Starter Panel: No</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="359"/>
        <source>Editing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="436"/>
        <source>Button </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="443"/>
        <source>(Button will be deleted)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="453"/>
        <source>Test</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="460"/>
        <source>Script is empty</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="522"/>
        <location filename="../panelgenerator.cpp" line="527"/>
        <source>New Button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="692"/>
        <source>Nothing to do...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="694"/>
        <source>Executing </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="699"/>
        <source>Unknown Command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="769"/>
        <source>Transition Panel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="773"/>
        <source>Tranisition to Panel &quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="773"/>
        <source>&quot;?
This panel has not been saved. You may lose changes.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="785"/>
        <source>Not loading panel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="789"/>
        <source>Not loading panel in edit mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="905"/>
        <source>Change URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="906"/>
        <source>URL:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="913"/>
        <source>Delete link</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="917"/>
        <source>Delete URL link?
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="928"/>
        <source>Change Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="929"/>
        <source>text:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="990"/>
        <source>Panels File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="992"/>
        <source>*.panels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1029"/>
        <source>Unknown File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1032"/>
        <source>This does not seem to be a valid PS Panels file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1046"/>
        <location filename="../panelgenerator.cpp" line="1071"/>
        <source>Found </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1046"/>
        <source> packets. Saving overwrites duplicate names.

Continue packet import?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1071"/>
        <source> panels. Ovewrite dpulicated IDs?

Selecting No will generate new IDs and append.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1143"/>
        <source>Coming soon.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1160"/>
        <source>Change Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1161"/>
        <location filename="../panelgenerator.cpp" line="1209"/>
        <source>Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1177"/>
        <source>Change ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1178"/>
        <source>ID:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1208"/>
        <source>New Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1243"/>
        <source>Save PS Panels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1244"/>
        <source>panels (*.panels)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PersistentConnection</name>
    <message>
        <location filename="../persistentconnection.ui" line="14"/>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="26"/>
        <source>Waiting...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="40"/>
        <source>Load</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="47"/>
        <source>Search Packets...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="61"/>
        <source>Raw</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="71"/>
        <source>ASCII</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="84"/>
        <source>ASCII. Press Enter to Send.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="94"/>
        <source>Send</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="104"/>
        <source>Append \r</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="114"/>
        <location filename="../persistentconnection.cpp" line="468"/>
        <source>Send File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="158"/>
        <source>Clear Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="165"/>
        <source>To Clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="185"/>
        <source>Resending(1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../persistentconnection.cpp" line="154"/>
        <location filename="../persistentconnection.cpp" line="156"/>
        <source>You:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../persistentconnection.cpp" line="470"/>
        <source>*.*</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../persistentconnection.cpp" line="511"/>
        <source>Copied</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../persistentconnection.cpp" line="512"/>
        <source>Output sent to your clipboard</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PersistentHTTP</name>
    <message>
        <location filename="../persistenthttp.ui" line="26"/>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../persistenthttp.ui" line="44"/>
        <source>Copy Code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../persistenthttp.ui" line="64"/>
        <source>.html View/Edit</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PostDataGen</name>
    <message>
        <location filename="../postdatagen.ui" line="14"/>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../postdatagen.ui" line="22"/>
        <source>Key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../postdatagen.ui" line="32"/>
        <source>Value</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../postdatagen.ui" line="42"/>
        <source>+</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../postdatagen.ui" line="51"/>
        <source>Params</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../postdatagen.cpp" line="30"/>
        <source>Data Generator</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PreviewFilter</name>
    <message>
        <location filename="../mainwindow.cpp" line="2726"/>
        <source>Multi-line editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2732"/>
        <source>Update</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2733"/>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../packet.cpp" line="266"/>
        <location filename="../settings.cpp" line="44"/>
        <source>Send</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../packet.cpp" line="267"/>
        <source>Send &lt;b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../packet.cpp" line="627"/>
        <source>Received an invalid MAC address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="47"/>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="50"/>
        <source>Resend</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="53"/>
        <source>To Address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="56"/>
        <source>To Port</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="59"/>
        <source>Method</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="62"/>
        <source>Request Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="65"/>
        <source>Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="68"/>
        <source>From IP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="71"/>
        <source>From Port</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="74"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="../settings.ui" line="14"/>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="24"/>
        <source>Network</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="30"/>
        <source>Basic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="36"/>
        <source>Enable UDP Servers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="45"/>
        <source>UDP Server Ports (comma-separated, 0 for random)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="52"/>
        <location filename="../settings.ui" line="77"/>
        <location filename="../settings.ui" line="102"/>
        <source>0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="61"/>
        <source>Enable TCP Servers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="70"/>
        <source>TCP Server Port (comma-separated, 0 for random)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="86"/>
        <source>Enable SSL/TLS Servers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="95"/>
        <source>SSL Server Port (comma-separated, 0 for random)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="111"/>
        <source>Set the server ports to 0 if you want to run multiple Packet Sender instances.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="125"/>
        <source>Translate macros when sending</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="132"/>
        <source>Send a basic response with macro support</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="141"/>
        <source>Response Data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="155"/>
        <source>ASCII</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="169"/>
        <location filename="../settings.ui" line="771"/>
        <location filename="../settings.ui" line="833"/>
        <location filename="../settings.ui" line="867"/>
        <location filename="../settings.ui" line="908"/>
        <location filename="../settings.ui" line="941"/>
        <source>HEX</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="197"/>
        <source>Additional UDP/TCP/SSL Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="205"/>
        <source>IPv4 Only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="218"/>
        <source>IPv6 Only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="230"/>
        <source>Bind This:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="240"/>
        <source>Your IP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="253"/>
        <source>Multi-Send Delay (sec)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="260"/>
        <source>0.0 for off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="271"/>
        <source>Cancel Resending after # packets</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="278"/>
        <source>0 for off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="287"/>
        <source>Attempt Receive Before Send</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="294"/>
        <source>500 ms delay after connect (slow devices)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="301"/>
        <source>Persistent TCP Connections</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="308"/>
        <source>Resolve DNS during input (old method)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="315"/>
        <source>Ignore SSL Errors (Wrong host, expired, self-signed, etc)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="328"/>
        <source>SSL Server may use an internal snake oil cert</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="337"/>
        <source>SSL CA Certificates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="344"/>
        <source>Path from where to load the CA certificats (leave empty for defaults)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="351"/>
        <location filename="../settings.ui" line="376"/>
        <location filename="../settings.ui" line="401"/>
        <source>Browse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="362"/>
        <source>SSL Local Certificate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="369"/>
        <source>File path for the client side local certificate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="387"/>
        <source>SSL Private Key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="394"/>
        <source>File path for the client side private key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="430"/>
        <source>HTTP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="436"/>
        <source>Automatically adjust ContentType when sending XML or JSON</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="458"/>
        <source>Generate Auth Header</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="469"/>
        <location filename="../settings.cpp" line="975"/>
        <source>Host</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="479"/>
        <source>Username/ClientID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="489"/>
        <source>Password/AccessCode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="499"/>
        <location filename="../settings.cpp" line="1046"/>
        <source>HTTP Header</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="530"/>
        <source>Delete Header</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="540"/>
        <source>Display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="548"/>
        <source>Saved Packet Display Order (Drag and Drop)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="555"/>
        <location filename="../settings.ui" line="583"/>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="560"/>
        <location filename="../settings.ui" line="588"/>
        <source>To IP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="565"/>
        <location filename="../settings.ui" line="593"/>
        <source>From IP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="576"/>
        <source>Traffic Log Display Order (Drag and Drop)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="601"/>
        <source>Use Default Order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="626"/>
        <source>Miscellaneous</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="632"/>
        <source>Use Dark Theme (requires restart)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="641"/>
        <source>Language (Requires Restart)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="650"/>
        <source>Copy to Clipboard button uses raw data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="657"/>
        <source>Rolling 100-entry traffic log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="664"/>
        <source>Restore previous session</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="671"/>
        <source>Periodically check for updates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="678"/>
        <source>Use ellipsis [...] for long data entries (helps performance)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="685"/>
        <source>Auto-Launch Starter Panel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="722"/>
        <source>Smart Responses</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="730"/>
        <source>Send a Smart Response with Macro Support</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="758"/>
        <source>Response 5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="766"/>
        <location filename="../settings.ui" line="828"/>
        <location filename="../settings.ui" line="862"/>
        <location filename="../settings.ui" line="903"/>
        <location filename="../settings.ui" line="936"/>
        <source>Mixed ASCII</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="779"/>
        <location filename="../settings.ui" line="844"/>
        <location filename="../settings.ui" line="882"/>
        <location filename="../settings.ui" line="895"/>
        <location filename="../settings.ui" line="928"/>
        <source>Enable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="786"/>
        <source>Response 4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="793"/>
        <source>If Packet data equals</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="800"/>
        <source>Reply with</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="807"/>
        <source>Encoding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="814"/>
        <source>Response 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="854"/>
        <source>Response 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="875"/>
        <source>Response 3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="963"/>
        <source>Available macros: {{DATE}} {{TIME}} {{RANDOM}} {{UNIXTIME}} {{UNIQUE}}</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="970"/>
        <source>Packet Sender will swap macro with a real value before sending</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="981"/>
        <source>{{DATE}} format (Requires Restart)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="998"/>
        <location filename="../settings.ui" line="1039"/>
        <source>Example</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="1022"/>
        <source>{{TIME}} format (Requires Restart)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="1083"/>
        <source>Online Documentation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="103"/>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="359"/>
        <source>Bad IP.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="363"/>
        <source>Packet Sender cannot bind invalid IP </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="377"/>
        <source>TCP and SSL non-zero port conflict.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="381"/>
        <source>Packet Sender cannot bind TCP and SSL to the same port.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="726"/>
        <source>Open Directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="747"/>
        <source>Choose Cert</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="747"/>
        <source>Certs (*.pem)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="763"/>
        <source>Choose Key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="763"/>
        <source>Keys (*.key, *.pem)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="975"/>
        <location filename="../settings.cpp" line="1044"/>
        <source>Key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="975"/>
        <location filename="../settings.cpp" line="1045"/>
        <source>Value</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="1040"/>
        <source>UN/ClientID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="1041"/>
        <source>PW/Access</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="1042"/>
        <source>HTTP Auth Header</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SubnetCalc</name>
    <message>
        <location filename="../subnetcalc.ui" line="14"/>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="26"/>
        <source>IP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="33"/>
        <source>IPv4 address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="44"/>
        <source>Subnet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="51"/>
        <source>Dotted or number of bits </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="66"/>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="76"/>
        <source>Calculated Start..</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="87"/>
        <source>End</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="97"/>
        <source>Calculated End...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="108"/>
        <source>Broadcast</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="118"/>
        <source>Broadcast...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="133"/>
        <source>Within subnet check</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="140"/>
        <source>IP Address...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="156"/>
        <source>Subnet Check Result...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="168"/>
        <source>Results log...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="177"/>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../subnetcalc.cpp" line="24"/>
        <source>IPv4 Subnet Calculator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../subnetcalc.cpp" line="26"/>
        <source>Your non-loopback addresses: 

</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../subnetcalc.cpp" line="263"/>
        <source>Within </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../subnetcalc.cpp" line="273"/>
        <source>No entries in subnet.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UDPFlooding</name>
    <message>
        <location filename="../udpflooding.ui" line="14"/>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../udpflooding.ui" line="24"/>
        <source>IP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../udpflooding.ui" line="38"/>
        <source>Port</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../udpflooding.ui" line="54"/>
        <source>Ascii</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../udpflooding.ui" line="76"/>
        <source>Delay (ms)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../udpflooding.ui" line="86"/>
        <source>Speed (MB/s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../udpflooding.ui" line="101"/>
        <source>0 or blank is no delay or max speed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../udpflooding.ui" line="110"/>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../udpflooding.ui" line="117"/>
        <source>Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../udpflooding.ui" line="139"/>
        <source>Waiting to send...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../udpflooding.cpp" line="25"/>
        <source>UDP Traffic Generator (Experimental)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../udpflooding.cpp" line="76"/>
        <location filename="../udpflooding.cpp" line="81"/>
        <source>Invalid</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WakeOnLAN</name>
    <message>
        <location filename="../wakeonlan.ui" line="14"/>
        <source>Wake-On-LAN</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../wakeonlan.ui" line="22"/>
        <source>Target MAC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../wakeonlan.ui" line="29"/>
        <source>01:23:45:67:89:ab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../wakeonlan.ui" line="36"/>
        <source>Port</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../wakeonlan.ui" line="59"/>
        <source>7</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../wakeonlan.ui" line="68"/>
        <source>9</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
